@@ -311,10 +311,11 @@ impl<H: Handler + 'static> Worker<H> {
         let mut wrt = BufWriter::new(stream);
 
         while self.keep_alive_loop(&mut rdr, &mut wrt, addr) {
-            if let Err(e) = self.set_read_timeout(*rdr.get_ref(), self.timeouts.keep_alive) {
-                info!("set_read_timeout keep_alive {:?}", e);
-                break;
-            }
+            //TODO set read timeout
+            // if let Err(e) = self.set_read_timeout(*rdr.get_ref(), self.timeouts.keep_alive) {
+            //     info!("set_read_timeout keep_alive {:?}", e);
+            //     break;
+            // }
         }
 
         self.handler.on_connection_end();
@@ -438,7 +439,7 @@ pub trait Handler: Sync + Send {
     /// Receives a `Request`/`Response` pair, and should perform some action on them.
     ///
     /// This could reading from the request, and writing to the response.
-    fn handle<'a, 'k>(&'a self, _: Request<'a, 'k>, _: Response<'a, Fresh>);
+    fn handle(&self, req: Request, resp: Response<'_, Fresh>);
 
     /// Called when a Request includes a `Expect: 100-continue` header.
     ///
@@ -460,7 +461,7 @@ pub trait Handler: Sync + Send {
 }
 
 impl<F> Handler for F where F: Fn(Request, Response<Fresh>), F: Sync + Send {
-    fn handle<'a, 'k>(&'a self, req: Request<'a, 'k>, res: Response<'a, Fresh>) {
+    fn handle(&self, req: Request, res: Response) {
         self(req, res)
     }
 }
@@ -501,7 +502,7 @@ mod tests {
     fn test_check_continue_reject() {
         struct Reject;
         impl Handler for Reject {
-            fn handle<'a, 'k>(&'a self, _: Request<'a, 'k>, res: Response<'a, Fresh>) {
+            fn handle(&self, _: Request, res: Response<'_, Fresh>) {
                 res.start().unwrap().end().unwrap();
             }
 
